=======================
Cooperative Dataclasses
=======================

.. role:: bash(code)
    :language: bash

.. role:: python(code)
   :language: python

This repository provides a version of dataclasses that can be used in
cooperative inheritance.
